@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2018 Losant IoT, Inc.
+Copyright (c) 2020 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -22,6 +22,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+
+import json
+
 """ Module for Losant API Me wrapper class """
 # pylint: disable=C0301
 
@@ -39,7 +42,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.addRecentItem.
+        all.User, me.*, or me.addRecentItem.
 
         Parameters:
         *  {hash} data - Object containing recent item info (https://api.losant.com/#/definitions/recentItem)
@@ -83,7 +86,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.changePassword.
+        all.User, me.*, or me.changePassword.
 
         Parameters:
         *  {hash} data - Object containing the password change info (https://api.losant.com/#/definitions/changePassword)
@@ -127,7 +130,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.delete.
+        all.User, me.*, or me.delete.
 
         Parameters:
         *  {hash} credentials - User authentication credentials (https://api.losant.com/#/definitions/userCredentials)
@@ -171,7 +174,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.disableTwoFactorAuth.
+        all.User, me.*, or me.disableTwoFactorAuth.
 
         Parameters:
         *  {hash} data - Object containing two factor auth properties (https://api.losant.com/#/definitions/disableTwoFactorAuth)
@@ -215,7 +218,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.disconnectGithub.
+        all.User, me.*, or me.disconnectGithub.
 
         Parameters:
         *  {string} losantdomain - Domain scope of request (rarely needed)
@@ -256,7 +259,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.disconnectTwitter.
+        all.User, me.*, or me.disconnectTwitter.
 
         Parameters:
         *  {string} losantdomain - Domain scope of request (rarely needed)
@@ -297,7 +300,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.enableTwoFactorAuth.
+        all.User, me.*, or me.enableTwoFactorAuth.
 
         Parameters:
         *  {hash} data - Object containing two factor auth properties (https://api.losant.com/#/definitions/enableTwoFactorAuth)
@@ -341,7 +344,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.SolutionUser.read, all.User, all.User.read, me.*, or me.fetchRecentItems.
+        all.User, all.User.read, me.*, or me.fetchRecentItems.
 
         Parameters:
         *  {string} parentId - Parent id of the recent list
@@ -388,11 +391,12 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.SolutionUser.read, all.User, all.User.read, me.*, or me.get.
+        all.User, all.User.read, me.*, or me.get.
 
         Parameters:
         *  {undefined} includeRecent - Should the user include recent app/dashboard info
-        *  {string} summaryExclude - List of summary fields to exclude from user summary
+        *  {string} summaryExclude - Comma-separated list of summary fields to exclude from user summary
+        *  {string} summaryInclude - Comma-separated list of summary fields to include in user summary
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -413,6 +417,8 @@ class Me(object):
             query_params["includeRecent"] = kwargs["includeRecent"]
         if "summaryExclude" in kwargs:
             query_params["summaryExclude"] = kwargs["summaryExclude"]
+        if "summaryInclude" in kwargs:
+            query_params["summaryInclude"] = kwargs["summaryInclude"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
@@ -434,10 +440,12 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.patch.
+        all.User, me.*, or me.patch.
 
         Parameters:
         *  {hash} user - Object containing new user properties (https://api.losant.com/#/definitions/mePatch)
+        *  {string} summaryExclude - Comma-separated list of summary fields to exclude from user summary
+        *  {string} summaryInclude - Comma-separated list of summary fields to include in user summary
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -457,6 +465,10 @@ class Me(object):
 
         if "user" in kwargs:
             body = kwargs["user"]
+        if "summaryExclude" in kwargs:
+            query_params["summaryExclude"] = kwargs["summaryExclude"]
+        if "summaryInclude" in kwargs:
+            query_params["summaryInclude"] = kwargs["summaryInclude"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
@@ -478,7 +490,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, all.User.read, me.*, or me.payloadCounts.
+        all.User, all.User.read, me.*, or me.payloadCounts.
 
         Parameters:
         *  {string} start - Start of range for payload count query (ms since epoch)
@@ -517,6 +529,48 @@ class Me(object):
 
         return self.client.request("GET", path, params=query_params, headers=headers, body=body)
 
+    def refresh_token(self, **kwargs):
+        """
+        Returns a new auth token based on the current auth token
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.User, or me.*.
+
+        Parameters:
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - Successful token regeneration (https://api.losant.com/#/definitions/authedUser)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  401 - Unauthorized error if authentication fails (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/me/refreshToken".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
     def transfer_resources(self, **kwargs):
         """
         Moves resources to a new owner
@@ -525,7 +579,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.transferResources.
+        all.User, me.*, or me.transferResources.
 
         Parameters:
         *  {hash} transfer - Object containing properties of the transfer (https://api.losant.com/#/definitions/resourceTransfer)
@@ -569,7 +623,7 @@ class Me(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.SolutionUser, all.User, me.*, or me.verifyEmail.
+        all.User, me.*, or me.verifyEmail.
 
         Parameters:
         *  {string} losantdomain - Domain scope of request (rarely needed)
